Function lookup_cot_type
pub fn lookup_cot_type(
cot_type: CoTType,
cot_classification: CotClassification,
) -> &'static strExpand description
A function to lookup the string from the CotDefinitions array
pub fn lookup_cot_type(
cot_type: CoTType,
cot_classification: CotClassification,
) -> &'static strA function to lookup the string from the CotDefinitions array